@@ -44,6 +44,11 @@ from ..geolib.objet import Objet
 #~ from ..geolib.constantes import NOM
 
 class MiniEditeur:
+    u"""Le mini éditeur de texte permet de taper du texte directement
+    dans le canevas, sans utiliser une boîte de dialogue.
+    Il est utilisé lorsqu'on crée un texte avec la souris,
+    ou lorsqu'on crée un objet géométrique (point, cercle...) qu'on
+    peut ainsi aussitôt nommer."""
     def __init__(self, parent):
         self.parent = parent
         self.objet = None
@@ -76,6 +81,12 @@ class MiniEditeur:
         self._display(self.texte)
 
     def cancel(self):
+        if self.objet._style.get('nouveau_texte'):
+            # Le pseudo-style `nouveau_texte` est utilisé pour indiquer qu'un texte
+            # vient juste d'être créé. Ceci permet que, lorsque l'utilisateur clique
+            # quelque part pour créer un texte, puis appuie sur [ESC], le texte
+            # soit aussitôt supprimé, au lieu de créer un texte vide.
+            self.parent.executer("%s.supprimer()" % self.objet.nom)
         self._display(None)
         self.objet = None
 
@@ -84,7 +95,12 @@ class MiniEditeur:
         canvas = self.parent
         panel = canvas.parent
         # NB: si aucun nom n'est rentré, [ENTREE] est un équivalent de [ECHAP].
-        if self.texte:
+        if not self.texte:
+            if self.objet._style.get('nouveau_texte'):
+                self.parent.executer("%s.supprimer()" % self.objet.nom)
+        else:
+            self.objet._style.pop('nouveau_texte', None)
+
             try: # si possible, on change le nom de l'objet ; sinon, on change son label.
                 nom = self.objet.nom
                 if isinstance(self.objet, Texte) or not re.match("""[A-Za-z_][A-Za-z0-9_'"`]*$""", self.texte):
@@ -106,7 +122,8 @@ class MiniEditeur:
             except:
                 self.display()
                 raise
-        self.cancel()
+        self._display(None)
+        self.objet = None
 
 
     def key(self, key, txt, modifiers):
@@ -440,6 +457,12 @@ class QtCanvas(FigureCanvasQTAgg, Canvas):
         mode = self.mode
         if ctrl_down(event):
             mode = ('select' if alt_down(event) else 'zoom')
+        elif self.select is None:
+            # Passera automatiquement en mode selection si la zone sélectionnée
+            # est assez grande (cela évite de créer une sélection alors que
+            # l'utilisateur a juste légèrement bougé la souris en cliquant !)
+            # Reste en mode selection si on y était déjà.
+            mode = ('auto_select' if self.action_en_cours != 'select' else 'select')
         if self.fixe and mode == 'zoom':
             # Zoom interdit (fenêtre d'affichage bloquée).
             mode = 'defaut'
@@ -507,13 +530,28 @@ class QtCanvas(FigureCanvasQTAgg, Canvas):
                 # lors de la sélection de la zone de zoom).
                 self.interrompre_action_en_cours()
 
+            px, py = lieu(event)
+            if self.action_en_cours == 'auto_select':
+                # Quand on clique dans le canevas, on déplace souvent légèrement la souris entre
+                # le moment où on enfonce le bouton de la souris et le moment ou on le relâche.
+                # Le canevas peut alors croire qu'on veut sélectionner une zone.
+                # Pour éviter ce problème, on choisit une taille de sélection minimale (abs(dx)+abs(dy)).
+                # Nota: une fois la sélection déclenchée, on peut éventuellement réduire la zone
+                # en deçà de cette taille minimale.
+                px0, py0 = self.pixels_left_down
+                if abs(px - px0) + abs(py - py0) > param.taille_selection_minimale:
+                    self.action_en_cours = 'select'
+
+            # Dans toutes les actions suivantes, on évite d'utiliser la méthode self.coordonnees()
+            # qui tient compte de l'aimantation de la grille, ce qui n'est pas souhaitable ici.
+
             if self.action_en_cours == 'select':
                 # Sélection simultanée de tous les objets d'une zone.
-                self.rectangle_selection(self.coordonnees_left_down, self.coordonnees(event))
+                self.rectangle_selection(self.coordonnees_left_down, self.pix2coo(px, py))
 
             elif self.action_en_cours == 'zoom':
                 # Sélection d'une zone pour zoomer.
-                self.rectangle_zoom(self.coordonnees_left_down, self.coordonnees(event))
+                self.rectangle_zoom(self.coordonnees_left_down, self.pix2coo(px, py))
 
             elif alt_down(event) or meta_down(event):
                 # Déplacement de l'étiquette d'un objet.
@@ -525,7 +563,7 @@ class QtCanvas(FigureCanvasQTAgg, Canvas):
                                 if objet.etiquette.distance_inf(x, y, param.precision_selection):
                                     self.etiquette_selectionnee = objet.etiquette
                                     x, y = self.etiquette_selectionnee.coordonnees
-                                    x1, y1 = self.coordonnees(event)
+                                    x1, y1 = self.pix2coo(px, py)
                                     self.decalage_coordonnees = x - x1, y - y1
                                     break
                             except:
@@ -684,7 +722,8 @@ class QtCanvas(FigureCanvasQTAgg, Canvas):
             # Cela permet :
             # - de savoir si un objet a été déplacé ("drag") ou non lors du clic.
             # - de sélectionner une zone.
-            self.coordonnees_left_down = x_clic, y_clic = self.coordonnees(event)
+            self.pixels_left_down = pxy = lieu(event)
+            self.coordonnees_left_down = x_clic, y_clic = self.pix2coo(*pxy)
             self.setFocus()
             if self.deplacable(self.select):
                 x, y = self.select.coordonnees
@@ -697,6 +736,7 @@ class QtCanvas(FigureCanvasQTAgg, Canvas):
                 menu.etiquette()
             else:
                 self.action_en_cours = self.test_mode(event)
+                self.coordonnees_rectangle_selection = None
 
 
     def onRightDown(self, event):
@@ -738,8 +778,9 @@ class QtCanvas(FigureCanvasQTAgg, Canvas):
             return
 
         action = self.action_en_cours
-        if action in ('zoom', 'select'):
-            (x0, y0), (x1, y1) = self.coordonnees_rectangle_selection
+        rect_select = self.coordonnees_rectangle_selection
+        if action in ('zoom', 'select') and rect_select is not None:
+            (x0, y0), (x1, y1) = rect_select
             if (x0, y0) != (x1, y1):
                 # Zoom sur la zone sélectionnée.
                 if action == 'zoom':
