@@ -26,7 +26,7 @@ from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 
 import re
 
-from sympy import sympify, oo, nan, limit, Symbol, Float, Rational, Wild, sqrt, S
+from sympy import oo, limit, Symbol, Float, Rational, Wild, sqrt, S
 
 from .tablatexlib import convertir_en_latex, test_parentheses, nice_str
 from ...mathlib.solvers import ensemble_definition
@@ -37,7 +37,7 @@ from ...mathlib.parsers import VAR
 from ... import param
 
 
-def _auto_tabvar(chaine='', derivee=True, limites=True, decimales=3, approche=False, parse_only=False):
+def _auto_tabvar(chaine='', derivee=True, limites=True, decimales=3, approche=False, parse_only=False, stretch=True):
     u"""Génère le code du tableau de variations d'une fonction à variable réelle.
 
     On suppose que la fonction est de classe C1 sur tout intervalle ouvert de son
@@ -135,7 +135,7 @@ def _auto_tabvar(chaine='', derivee=True, limites=True, decimales=3, approche=Fa
                 if x in infs:
                     droite = nice_str2(limit(expr, var, x, dir = '+'))
             fx = '%s%s%s' % (gauche, symb, droite)
-            
+
         # Affichage de f'(x) (seulement si f'(x)=0 ou f'(x) non défini).
         if x in (-oo, oo):
             dfx = ''
@@ -147,7 +147,7 @@ def _auto_tabvar(chaine='', derivee=True, limites=True, decimales=3, approche=Fa
             return '(%s;%s;%s)' % (nice_str2(x), fx, dfx)
         else:
             return '(%s;%s)' % (nice_str2(x), fx)
-            
+
     def _code_inter(a, b):
         u"Retourne les variations entre a et b."
         if a == -oo and b == +oo:
@@ -212,13 +212,13 @@ def _auto_tabvar(chaine='', derivee=True, limites=True, decimales=3, approche=Fa
         print 'Code TABVar:', code
     if parse_only:
         return code
-    return tabvar(code, derivee=derivee) + '% ' + chaine_initiale + '\n'
+    return tabvar(code, derivee=derivee, stretch=stretch) + '% ' + chaine_initiale + '\n'
 
 
 
 
 
-def tabvar(chaine="", derivee=True, limites=True, decimales=3, approche=False):
+def tabvar(chaine="", derivee=True, limites=True, decimales=3, approche=False, stretch=True):
     u"""Indiquer les variations de la fonction.
 
 Exemples :
@@ -229,9 +229,8 @@ x;\\sqrt{x};(\\sqrt{x})': 0;0;| << +oo;+oo"""
 
 
     #ligne_variable = ligne_derivee = ligne_fonction = ""
-
     if not ':' in chaine and not '>>' in chaine and not '==' in chaine and not '<<' in chaine:
-        return _auto_tabvar(chaine, derivee=derivee, limites=limites, decimales=decimales, approche=approche)
+        return _auto_tabvar(chaine, derivee=derivee, limites=limites, decimales=decimales, approche=approche, stretch=stretch)
 
     chaine = chaine.replace("-oo", "-\\infty").replace("+oo", "+\\infty")
 
@@ -337,8 +336,11 @@ x;\\sqrt{x};(\\sqrt{x})': 0;0;| << +oo;+oo"""
     portion = 0 # indique la derniere portion traitee (les portions sont delimitees par les bornes de l'ensemble de definition et les valeurs interdites)
     debut = True
 
-    def en_latex(chaine):
-        return convertir_en_latex(chaine)[1:-1]
+    def en_latex(chaine, stretch=False):
+        if stretch:
+            return '\\TVstretch{%s}' % convertir_en_latex(chaine)[1:-1]
+        else:
+            return convertir_en_latex(chaine)[1:-1]
 
     # Deuxieme et dernier balayage :
     # on parcourt maintenant la liste pour construire colonne par colonne le tableau de variations.
@@ -380,20 +382,23 @@ x;\\sqrt{x};(\\sqrt{x})': 0;0;| << +oo;+oo"""
             # les limites a gauche et a droite, separees par un "|". (Idem pour f'(x)).
 
 
+            # largeur : nombre de colonnes à créer pour la valeur.
+            # Si c'est une valeur simple, 1 colonne suffit.
+            # Par contre, si x est une valeur interdite pour f ou f', il faudra
+            # 3 colonnes (limite à gauche, double barre, limite à droite).
             largeur = max((3 if "|" in val else 1) for val in valeurs)
-            # 3 si x est une valeur interdite pour f ou f' (ie. une valeur contient un "|"), 1 sinon.
 
             if largeur == 3: # x est une valeur interdite pour f(x) ou f'(x)
-                ligne_variable += " &" + en_latex(valeurs[0]) + "& "
+                ligne_variable += " &" + en_latex(valeurs[0], stretch=stretch) + "& "
 
                 vals_fonc = valeurs[1].split("|")
                 if len(vals_fonc) == 2: # x est une valeur interdite pour f(x)
                     portion += 1 # on change de portion
-                    ligne_fonction += en_latex(vals_fonc[0]) + "&\\dbarre&" \
+                    ligne_fonction += en_latex(vals_fonc[0], stretch=stretch) + "&\\dbarre&" \
                                     + "\\niveau{" + str(1 - niveaux[portion][0]) +"}{" + str(ecart_maximal + 1) + "}" \
-                                    + en_latex(vals_fonc[1])
+                                    + en_latex(vals_fonc[1], stretch=stretch)
                 else:
-                    ligne_fonction += " &" + en_latex(vals_fonc[0]) + "&"
+                    ligne_fonction += " &" + en_latex(vals_fonc[0], stretch=stretch) + "&"
 
                 if len(valeurs) < 3: # le nombre derive n'est pas specifie
                     valeurs.append("|") # si la fonction n'est pas definie en x, sa derivee non plus
